==> vue-avatar-2.21.0.tgz: package/lib/index.js <==
import { defineComponent, $prefix, setup, h } from '@opentinyvue/vue-common';
import { renderless, api } from '@opentinyvue/vue-renderless/avatar/vue';
import '@opentinyvue/vue-theme-mobile/avatar/index.css';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var $constants = {
  COMPONENT_PREFIX: "tiny-mobile-avatar",
  ICON: "icon"
};
var __vue2_script = defineComponent({
  name: $prefix + "Avatar",
  props: {
    _constants: {
      type: Object,
      default: function _default() {
        return $constants;
      }
    },
    alt: String,
    error: Function,
    fit: {
      type: String,
      default: "cover"
    },
    icon: Object,
    shape: {
      type: String,
      default: "circle",
      validator: function validator(val) {
        return ~["circle", "square"].indexOf(val);
      }
    },
    size: {
      type: [Number, String],
      validator: function validator2(val) {
        return typeof val === "string" ? ~["large", "medium", "small"].indexOf(val) : typeof val === "number";
      }
    },
    src: String,
    srcSet: String
  },
  setup: function setup$1(props, context) {
    return setup({
      props,
      context,
      renderless,
      api,
      mono: true,
      h
    });
  },
  render: function render() {
    var _this = this;
    var h2 = arguments[0];
    var alt = this.alt, fit = this.fit, Icon = this.icon, size = this.size, src = this.src, srcSet = this.srcSet, _this$state = this.state, isImageExist = _this$state.isImageExist, avatarClass = _this$state.avatarClass;
    var hasImageSrc = isImageExist && src;
    var sizeStyle = {};
    if (typeof size === "number") {
      sizeStyle = {
        height: size + "px",
        width: size + "px",
        lineHeight: size + "px"
      };
    }
    var renderAvatar = function renderAvatar2() {
      if (hasImageSrc) {
        return h2("img", {
          "attrs": {
            "src": src,
            "alt": alt,
            "srcSet": srcSet
          },
          "style": {
            "object-fit": fit
          },
          "on": {
            "error": _this.handleError
          }
        });
      }
      if (Icon) {
        return h2(Icon);
      }
      return _this.$slots.default && _this.$slots.default();
    };
    return h2("span", {
      "class": avatarClass,
      "style": sizeStyle
    }, [renderAvatar()]);
  }
});
var __vue2_render, __vue2_staticRenderFns;
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, __vue2_render, __vue2_staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var Avatar = /* @__PURE__ */ function() {
  return __component__.exports;
}();
var version = "2.21.0";
Avatar.install = function(Vue) {
  Vue.component(Avatar.name, Avatar);
};
Avatar.version = version;

export { Avatar as default };

==> vue-avatar-3.21.0.tgz: package/lib/index.js <==
import { createVNode } from "vue";
import { defineComponent, $prefix, setup as _setup, h } from "@opentinyvue/vue-common";
import { renderless, api } from "@opentinyvue/vue-renderless/avatar/vue";
import "@opentinyvue/vue-theme-mobile/avatar/index.css";
var $constants = {
  COMPONENT_PREFIX: "tiny-mobile-avatar",
  ICON: "icon"
};
var _sfc_main = /* @__PURE__ */ defineComponent({
  name: $prefix + "Avatar",
  props: {
    _constants: {
      type: Object,
      default: function _default() {
        return $constants;
      }
    },
    alt: String,
    error: Function,
    fit: {
      type: String,
      default: "cover"
    },
    icon: Object,
    shape: {
      type: String,
      default: "circle",
      validator: function validator(val) {
        return ~["circle", "square"].indexOf(val);
      }
    },
    size: {
      type: [Number, String],
      validator: function validator2(val) {
        return typeof val === "string" ? ~["large", "medium", "small"].indexOf(val) : typeof val === "number";
      }
    },
    src: String,
    srcSet: String
  },
  setup: function setup(props, context) {
    return _setup({
      props,
      context,
      renderless,
      api,
      mono: true,
      h
    });
  },
  render: function render() {
    var _this = this;
    var alt = this.alt, fit = this.fit, Icon = this.icon, size = this.size, src = this.src, srcSet = this.srcSet, _this$state = this.state, isImageExist = _this$state.isImageExist, avatarClass = _this$state.avatarClass;
    var hasImageSrc = isImageExist && src;
    var sizeStyle = {};
    if (typeof size === "number") {
      sizeStyle = {
        height: size + "px",
        width: size + "px",
        lineHeight: size + "px"
      };
    }
    var renderAvatar = function renderAvatar2() {
      if (hasImageSrc) {
        return createVNode("img", {
          "src": src,
          "alt": alt,
          "srcSet": srcSet,
          "style": {
            "object-fit": fit
          },
          "onError": _this.handleError
        }, null);
      }
      if (Icon) {
        return createVNode(Icon, null, null);
      }
      return _this.$slots.default && _this.$slots.default();
    };
    return createVNode("span", {
      "class": avatarClass,
      "style": sizeStyle
    }, [renderAvatar()]);
  }
});
var version = "3.21.0";
_sfc_main.install = function(Vue) {
  Vue.component(_sfc_main.name, _sfc_main);
};
_sfc_main.version = version;
export {
  _sfc_main as default
};
